@@ -1,17 +1,12 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2021 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import builtins
 import collections
@@ -81,6 +76,7 @@ def type_sorting_key(t):
         raise InvalidArgument(f"thing={t} must be a type")  # pragma: no cover
     if t is None or t is type(None):  # noqa: E721
         return (-1, repr(t))
+    t = getattr(t, "__origin__", t)
     if not isinstance(t, type):  # pragma: no cover
         # Some generics in the typing module are not actually types in 3.7
         return (2, repr(t))
@@ -474,6 +470,22 @@ if zoneinfo is not None:  # pragma: no branch
     _global_type_lookup[zoneinfo.ZoneInfo] = st.timezones()
 if PYPY:
     _global_type_lookup[builtins.sequenceiterator] = st.builds(iter, st.tuples())  # type: ignore
+try:
+    BaseExceptionGroup  # type: ignore # noqa
+except NameError:
+    pass
+else:  # pragma: no cover
+    _global_type_lookup[BaseExceptionGroup] = st.builds(  # type: ignore
+        BaseExceptionGroup,  # type: ignore
+        st.text(),
+        st.lists(st.from_type(BaseException), min_size=1),
+    )
+    _global_type_lookup[ExceptionGroup] = st.builds(  # type: ignore
+        ExceptionGroup,  # type: ignore
+        st.text(),
+        st.lists(st.from_type(Exception), min_size=1),
+    )
+
 
 _global_type_lookup[type] = st.sampled_from(
     [type(None)] + sorted(_global_type_lookup, key=str)
